summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2018-09-27 16:03:51 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2018-09-27 16:03:51 +0900
commit2ead41ab9a2ece8c178a264e2d4e1d8867b8dadb (patch)
treeff5164e111972aa5599cc86d3870881bf65b0c15
parent0517447cd15a0cb11b8b480f43918935d3311d33 (diff)
downloadpytqt-2ead41ab.tar.gz
pytqt-2ead41ab.zip
qt -> tqt conversion:
QTDIR -> TQTDIR QTDOC -> TQTDOC INCDIR_QT -> INCDIR_TQT LIBDIR_QT -> LIBDIR_TQT QT_INC -> TQT_INC QT_LIB -> TQT_LIB Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
-rw-r--r--build.py4
-rw-r--r--configure.py20
-rwxr-xr-xexamples3/tablestatistics.py2
-rw-r--r--pylupdate3/pylupdate.pro.in6
-rw-r--r--pyuic2/pyuic.pro.in2
-rw-r--r--pyuic3/pyuic.pro.in8
6 files changed, 21 insertions, 21 deletions
diff --git a/build.py b/build.py
index db866f8..3a4402b 100644
--- a/build.py
+++ b/build.py
@@ -246,7 +246,7 @@ def moduleChecks(maindir):
# Check for the tqui library.
if config.qt_version >= 0x030000:
if sys.platform == "win32":
- tquilib = r"$(QTDIR)\lib\tqui.lib"
+ tquilib = r"$(TQTDIR)\lib\tqui.lib"
else:
tquilib = "-ltqui"
@@ -578,7 +578,7 @@ def main(argv):
if config.qt_version >= 0x030100:
if sys.platform == "win32":
- qaclib = r"$(QTDIR)\lib\qassistantclient.lib"
+ qaclib = r"$(TQTDIR)\lib\qassistantclient.lib"
else:
qaclib = "-lqassistantclient"
diff --git a/examples3/tablestatistics.py b/examples3/tablestatistics.py
index ee1f0f7..e0835bb 100755
--- a/examples3/tablestatistics.py
+++ b/examples3/tablestatistics.py
@@ -52,7 +52,7 @@ class Table(TQTable):
def initTable(self):
# read all the TQt source and header files into a list
all = []
- qtdir = os.getenv("QTDIR")
+ qtdir = os.getenv("TQTDIR")
for i in dirs:
dir = TQDir(os.path.join(qtdir, "src", i))
lst = TQStringList(dir.entryList("*.cpp; *.h"))
diff --git a/pylupdate3/pylupdate.pro.in b/pylupdate3/pylupdate.pro.in
index 51f45a9..0a39857 100644
--- a/pylupdate3/pylupdate.pro.in
+++ b/pylupdate3/pylupdate.pro.in
@@ -23,7 +23,7 @@ SOURCES = fetchtr.cpp \
metatranslator.cpp \
proparser.cpp
-rbprof:exists($(QTDIR)/src/qt_professional.pri) {
- QT_SOURCE_TREE = $(QTDIR)
- include($(QTDIR)/src/qt_professional.pri)
+rbprof:exists($(TQTDIR)/src/qt_professional.pri) {
+ QT_SOURCE_TREE = $(TQTDIR)
+ include($(TQTDIR)/src/qt_professional.pri)
}
diff --git a/pyuic2/pyuic.pro.in b/pyuic2/pyuic.pro.in
index e81b138..beeea65 100644
--- a/pyuic2/pyuic.pro.in
+++ b/pyuic2/pyuic.pro.in
@@ -8,7 +8,7 @@
TEMPLATE = app
CONFIG = qt console warn_on release
-INCLUDEPATH = @BLX_INCLUDEPATH@ $(QTDIR)/src/3rdparty/zlib
+INCLUDEPATH = @BLX_INCLUDEPATH@ $(TQTDIR)/src/3rdparty/zlib
DEFINES = UIC @BLX_DEFINES@
DESTDIR = @PYQT_BINDIR@
diff --git a/pyuic3/pyuic.pro.in b/pyuic3/pyuic.pro.in
index 7b5b911..5c9b3e8 100644
--- a/pyuic3/pyuic.pro.in
+++ b/pyuic3/pyuic.pro.in
@@ -8,7 +8,7 @@
TEMPLATE = app
CONFIG += qt console warn_on release @PYQT_RBPROF@
-INCLUDEPATH += @BLX_INCLUDEPATH@ $(QTDIR)/src/3rdparty/zlib
+INCLUDEPATH += @BLX_INCLUDEPATH@ $(TQTDIR)/src/3rdparty/zlib
DEFINES += UIC QT_INTERNAL_XML @BLX_DEFINES@
DESTDIR = @PYQT_BINDIR@
@@ -30,7 +30,7 @@ SOURCES = main.cpp \
domtool.cpp \
parser.cpp
-rbprof:exists($(QTDIR)/src/qt_professional.pri) {
- QT_SOURCE_TREE = $(QTDIR)
- include($(QTDIR)/src/qt_professional.pri)
+rbprof:exists($(TQTDIR)/src/qt_professional.pri) {
+ QT_SOURCE_TREE = $(TQTDIR)
+ include($(TQTDIR)/src/qt_professional.pri)
}
diff --git a/configure.py b/configure.py
index 133f1ae..39057b6 100644
--- a/configure.py
+++ b/configure.py
@@ -41,7 +41,7 @@ sip_min_version = 0x040800
# Try and find a TQt installation to use as the default.
try:
- qt_dir = os.environ["QTDIR"]
+ qt_dir = os.environ["TQTDIR"]
except KeyError:
qt_dir = ""
@@ -1070,12 +1070,12 @@ def get_build_macros(overrides):
# Add the TQt specific macros to the default.
names = sipcfg.build_macros().keys()
- names.append("INCDIR_QT")
- names.append("LIBDIR_QT")
+ names.append("INCDIR_TQT")
+ names.append("LIBDIR_TQT")
names.append("MOC")
- # Make sure $QTDIR reflects any directory passed on the command line.
- os.environ["QTDIR"] = qt_dir
+ # Make sure $TQTDIR reflects any directory passed on the command line.
+ os.environ["TQTDIR"] = qt_dir
properties = {
"QT_INSTALL_BINS": os.path.join(qt_dir, "bin"),
@@ -1097,17 +1097,17 @@ def check_qt_installation(macros):
# Set the TQt include and lib directories.
global qt_incdir, qt_libdir
- qt_incdir = macros["INCDIR_QT"]
+ qt_incdir = macros["INCDIR_TQT"]
if not qt_incdir:
qt_incdir = os.path.join(qt_dir, "include")
- macros["INCDIR_QT"] = qt_incdir
+ macros["INCDIR_TQT"] = qt_incdir
- qt_libdir = macros["LIBDIR_QT"]
+ qt_libdir = macros["LIBDIR_TQT"]
if not qt_libdir:
qt_libdir = os.path.join(qt_dir, "lib")
- macros["LIBDIR_QT"] = qt_libdir
+ macros["LIBDIR_TQT"] = qt_libdir
# Check the TQt header files have been installed. Quietly check for TQt v4.
qt4_d = os.path.join(qt_incdir, "TQtCore")
@@ -1399,7 +1399,7 @@ def main(argv):
# Check that we know the name of the TQt root directory.
if not qt_dir:
- sipconfig.error("A TQt installation could not be found. Use use the -q argument or the QTDIR environment variable to explicitly specify the correct directory.")
+ sipconfig.error("A TQt installation could not be found. Use use the -q argument or the TQTDIR environment variable to explicitly specify the correct directory.")
# When building static libraries, signed interpreter checking makes no
# sense.